@@ -3,107 +3,64 @@ use warnings;
 
 package Net::FreshBooks::API::Invoice;
 BEGIN {
-  $Net::FreshBooks::API::Invoice::VERSION = '0.14';
+  $Net::FreshBooks::API::Invoice::VERSION = '0.15';
 }
 
 use Moose;
 extends 'Net::FreshBooks::API::Base';
+with 'Net::FreshBooks::API::Role::CRUD';
+with 'Net::FreshBooks::API::Role::LineItem';
+with 'Net::FreshBooks::API::Role::SendBy';
 
-use Net::FreshBooks::API::InvoiceLine;
-use Net::FreshBooks::API::Links;
-
-my $fields = _fields();
-foreach my $method ( keys %{$fields} ) {
-    has $method => (  is => $fields->{$method}->{mutable} ? 'rw' : 'ro' );
-}
+has $_ => ( is => _fields()->{$_}->{is} ) for sort keys %{ _fields() };
 
 sub _fields {
     return {
-        invoice_id => { mutable => 0, },
-        client_id  => { mutable => 1, },
 
-        number             => { mutable => 1, },
-        amount             => { mutable => 0, },
-        amount_outstanding => { mutable => 0, },
-        status             => { mutable => 1, },
-        date               => { mutable => 1, },
-        po_number          => { mutable => 1, },
-        discount           => { mutable => 1, },
-        notes              => { mutable => 1, },
-        terms              => { mutable => 1, },
-        currency_code      => { mutable => 1, },
-        folder             => { mutable => 1, },
-        language           => { mutable => 1, },
-        return_uri         => { mutable => 1, },
-        updated            => { mutable => 0, },
+        amount        => { is => 'ro' },
+        client_id     => { is => 'rw' },
+        currency_code => { is => 'rw' },
+        date          => { is => 'rw' },
+        discount      => { is => 'rw' },
+        first_name    => { is => 'rw' },
+        language      => { is => 'rw' },
+        last_name     => { is => 'rw' },
+        notes         => { is => 'rw' },
+        organization  => { is => 'rw' },
+        p_city        => { is => 'rw' },
+        p_code        => { is => 'rw' },
+        p_country     => { is => 'rw' },
+        p_state       => { is => 'rw' },
+        p_street1     => { is => 'rw' },
+        p_street2     => { is => 'rw' },
+        po_number     => { is => 'rw' },
+        status        => { is => 'rw' },
+        terms         => { is => 'rw' },
+        vat_name      => { is => 'rw' },
+        vat_number    => { is => 'rw' },
 
-        links => {
-            mutable      => 0,
-            made_of      => 'Net::FreshBooks::API::Links',
-            presented_as => 'single',
-        },
-
-        recurring_id => { mutable => 0, },
-
-        organization => { mutable => 1, },
-        first_name   => { mutable => 1, },
-        last_name    => { mutable => 1, },
-        p_street1    => { mutable => 1, },
-        p_street2    => { mutable => 1, },
-        p_city       => { mutable => 1, },
-        p_state      => { mutable => 1, },
-        p_country    => { mutable => 1, },
-        p_code       => { mutable => 1, },
-        vat_name     => { mutable => 1, },
-        vat_number   => { mutable => 1, },
-
-        lines => {
-            mutable      => 1,
+        # custom fields
+        amount_outstanding => { is => 'ro' },
+        folder             => { is => 'rw' },
+        invoice_id         => { is => 'ro' },
+        lines              => {
+            is           => 'rw',
             made_of      => 'Net::FreshBooks::API::InvoiceLine',
             presented_as => 'array',
         },
+        links => {
+            is           => 'ro',
+            made_of      => 'Net::FreshBooks::API::Links',
+            presented_as => 'single',
+        },
+        number       => { is => 'rw' },
+        recurring_id => { is => 'ro' },
+        return_uri   => { is => 'rw' },
+        updated      => { is => 'ro' },
+
     };
 }
 
-sub add_line {
-    my $self      = shift;
-    my $line_args = shift;
-
-    push @{ $self->{lines} ||= [] },
-        Net::FreshBooks::API::InvoiceLine->new($line_args);
-
-    return 1;
-}
-
-sub send_by_email {
-    my $self = shift;
-    return $self->_send_using('sendByEmail');
-}
-
-sub send_by_snail_mail {
-    my $self = shift;
-    return $self->_send_using('sendBySnailMail');
-}
-
-sub _send_using {
-    my $self = shift;
-    my $how  = shift;
-
-    my $method   = $self->method_string($how);
-    my $id_field = $self->id_field;
-
-    my $res = $self->send_request(
-        {   _method   => $method,
-            $id_field => $self->$id_field,
-        }
-    );
-
-    # refetch the invoice so that the flags are updated.
-    $self->get( { invoice_id => $self->invoice_id } );
-
-    return 1;
-}
-
 __PACKAGE__->meta->make_immutable();
 
 1;
@@ -118,7 +75,7 @@ Net::FreshBooks::API::Invoice
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -131,6 +88,50 @@ Create an invoice in the FreshBooks system.
 
 my $invoice = $fb->invoice->create({...});
 
+=head2 get
+
+    my $invoice = $fb->invoice->get({ invoice_id => $invoice_id });
+
+=head2 delete
+
+    my $invoice = $fb->invoice->get({ invoice_id => $invoice_id });
+    $invoice->delete;
+
+=head2 update
+
+    # update after edits
+    $invoice->organization('Perl Foundation');
+    $invoice->update;
+
+    # or immediately
+    $invoice->update( { organization => 'Perl Foundation', } );
+
+=head2 links
+
+Returns a L<Net::FreshBooks::API::Links> object, which returns FreshBooks
+URLs.
+
+    print "send this url to client: " . $invoice->links->client_view;
+
+=head2 list
+
+Returns a L<Net::FreshBooks::API::Iterator> object.
+
+    # list unpaid invoices
+    my $invoices = $fb->invoice->list({ status => 'unpaid' });
+
+    while ( my $invoice = $invoices->list ) {
+        print $invoice->invoice_id, "\n";
+    }
+
+=head2 lines
+
+Returns an ARRAYREF of Net::FreshBooks::API::InvoiceLine objects
+
+    foreach my $line ( @{ $invoice->lines } ) {
+        print $line->amount, "\n";
+    }
+
 =head2 add_line
 
 Create a new L<Net::FreshBooks::API::InvoiceLine> object and add it to the end
@@ -160,48 +161,9 @@ Send the invoice by snail mail.
 
   my $result = $invoice->send_by_snail_mail();
 
-=head2 update
-
-Please see client->update for an example of how to use this method.
-
-=head2 get
-
-    my $invoice = $fb->invoice->get({ invoice_id => $invoice_id });
-
-=head2 delete
-
-    my $invoice = $fb->invoice->get({ invoice_id => $invoice_id });
-    $invoice->delete;
-
-=head2 links
-
-Returns a L<Net::FreshBooks::API::Links> object, which returns FreshBooks
-URLs.
-
-    print "send this url to client: " . $invoice->links->client_view;
-
-=head2 list
-
-Returns a L<Net::FreshBooks::API::Iterator> object.
-
-    # list unpaid invoices
-    my $invoices = $fb->invoice->list({ status => 'unpaid' });
-
-    while ( my $invoice = $invoices->list ) {
-        print $invoice->invoice_id, "\n";
-    }
-
-=head2 lines
-
-Returns an ARRAYREF of Net::FreshBooks::API::InvoiceLine objects
-
-    foreach my $line ( @{ $invoice->lines } ) {
-        print $line->amount, "\n";
-    }
-
 =head1 DESCRIPTION
 
-This class gives you object to FreshBooks invoice information.
+This class gives you access to FreshBooks invoice information.
 L<Net::FreshBooks::API> will construct this object for you.
 
 =head1 AUTHORS
